/*
 * PROGRAMME DE CONVERTION D'UN POTENTIOMETRE ANALOGIQUE VERS UNE ROUE CODEUSE (A, B et Index)
 * Par Christophe Girardot Aka Aganyte
 * Décembre 2017
 * 
 * Si 1024 pas pour 280° alors (1024 x 360°) / 280° = 1316 pas par tours => /4 = 329 (valeur à rentrer dans le logiciel, 329)
 * 
 */

#include  "Configuration.h"
#include  <avr/pgmspace.h>
#include  "Incremental.h"

//#define   DEBUG       // Activation des messages de debuggages
//#define   ITERATION   // Activation de l'affichage du nombre de convertion par seconde
//#define   CONVERT     // Activation de l'affichage de Analog_Position et Encoder_Position

void setup() 
{
  // définition des entrées/sorties
  pinMode(Potentiometer,INPUT);
  pinMode(A,OUTPUT);
  pinMode(B,OUTPUT);
  pinMode(Index,OUTPUT);

  // Activation de la liaison série si DEBUT actif
  #ifdef  DEBUG
    Serial.begin(9600);
  #endif
}

void loop() 
{
  int Encoder_Position = 511;
  int Analog_Position = 511;

  #ifdef  DEBUG
    long Time = millis();
    unsigned long iteration = 0;
    while(millis() - Time < 10000)
  #else
    while(1)
  #endif
  {
    // Lecture du potentiomètre
    Analog_Position = analogRead(Potentiometer);

    // Déplacer la roue codeuse d'un cran
    if( Analog_Position > Encoder_Position )
      Encoder_Position++;
    else if( Analog_Position < Encoder_Position)
      Encoder_Position--;

    // Gestion de l'index
    if(Encoder_Position == 511)
      digitalWrite( Index, HIGH );
    else
      digitalWrite( Index, LOW );

    // Gestion des sorties A et B
    digitalWrite( A, pgm_read_byte_near(IncrementalA + Encoder_Position) );
    digitalWrite( B, pgm_read_byte_near(IncrementalB + Encoder_Position) );

    #ifdef  ITERATION
      iteration++;
    #endif

    #ifdef  CONVERT
      Serial.print(Analog_Position);
      Serial.print(" ");
      Serial.println(Encoder_Position);
    #endif
   }
   #ifdef  ITERATION
    Serial.println(iteration);
   #endif
}
